跳到主要内容

GraphicsCaptureApiError

搜索

枚举 GraphicsCaptureApiError 

源代码
pub enum GraphicsCaptureApiError<E> {
    FailedToJoinThread,
    FailedToInitWinRT,
    FailedToCreateDispatcherQueueController,
    FailedToShutdownDispatcherQueue,
    FailedToSetDispatcherQueueCompletedHandler,
    ItemConvertFailed,
    DirectXError(Error),
    GraphicsCaptureApiError(Error),
    NewHandlerError(E),
    FrameHandlerError(E),
}
展开描述

在初始化和运行 Windows Graphics Capture 流水线时可能发生的错误。

变体



FailedToJoinThread

工作线程的 join 失败(panic 或操作系统级别的 join 错误)。



FailedToInitWinRT

无法为多线程单元初始化 Windows Runtime。

RoInitialize(RO_INIT_MULTITHREADED) 返回 S_FALSE 之外的错误时发生。



FailedToCreateDispatcherQueueController

为消息循环创建调度器队列控制器失败。



FailedToShutdownDispatcherQueue

关闭调度器队列失败。



FailedToSetDispatcherQueueCompletedHandler

注册调度器队列完成处理器失败。



ItemConvertFailed

所提供的项无法转换为 GraphicsCaptureItem

当传入 crate::settings::Settings 的项调用 [crate::settings::TryIntoCaptureItemWithDetails::try_into_capture_item_with_details] 失败时会发生这种情况。



DirectXError(Error)

底层 Direct3D (D3D11) 错误。

包装了 crate::d3d11::Error



GraphicsCaptureApiError(Error)

由 Windows Graphics Capture API 包装器产生的错误。

包装了 crate::graphics_capture_api::Error



NewHandlerError(E)

通过 GraphicsCaptureApiHandler::new 构造时由用户处理器返回的错误。



FrameHandlerError(E)

在帧处理期间通过 GraphicsCaptureApiHandler::on_frame_arrived 或从 GraphicsCaptureApiHandler::on_closed 由用户处理器返回的错误。

trait 实现

源代码

impl<E: Clone> Clone for GraphicsCaptureApiError<E>

源代码

fn clone(&self) -> GraphicsCaptureApiError<E>

返回该值的一个副本。 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 阅读更多
源代码

impl<E: Debug> Debug for GraphicsCaptureApiError<E>

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl<E> Display for GraphicsCaptureApiError<E>
where E: Display,

源代码

fn fmt(&self, __formatter: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl<E> Error for GraphicsCaptureApiError<E>
where Self: Debug + Display,

源代码

fn source(&self) -> Option<&(dyn Error + 'static)>

返回此错误的更底层来源(若有)。 阅读更多
1.0.0 · 源代码

fn description(&self) -> &str

👎Deprecated since 1.42.0: use the Display impl or to_string()
1.0.0 · 源代码

fn cause(&self) -> Option<&dyn Error>

👎Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
源代码

fn provide<'a>(&'a self, request: &mut Request<'a>)

🔬This is a nightly-only experimental API. (error_generic_member_access)
Provides type-based access to context intended for error reports. 阅读更多
源代码

impl<E> From<Error> for GraphicsCaptureApiError<E>

源代码

fn from(source: Error) -> Self

从输入类型转换为该类型。
源代码

impl<E> From<GraphicsCaptureApiError<E>> for CaptureControlError<E>

源代码

fn from(source: GraphicsCaptureApiError<E>) -> Self

从输入类型转换为该类型。
源代码

impl<E: PartialEq> PartialEq for GraphicsCaptureApiError<E>

源代码

fn eq(&self, other: &GraphicsCaptureApiError<E>) -> bool

测试 selfother 的值是否相等,被 == 使用。
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。 The default implementation is almost always sufficient, and should not be overridden without very good reason.
源代码

impl<E: Eq> Eq for GraphicsCaptureApiError<E>

源代码

impl<E> StructuralPartialEq for GraphicsCaptureApiError<E>

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

调用 U::from(self)

That is, this conversion is whatever the implementation of From<T> for U 的实现方式。

源代码

impl<T> IntoEither for T

源代码

fn into_either(self, into_left: bool) -> Either<Self, Self>

Converts self into a Left variant of Either<Self, Self> if into_left is true. Converts self into a Right variant of Either<Self, Self> otherwise. 阅读更多
源代码

fn into_either_with<F>(self, into_left: F) -> Either<Self, Self>
where F: FnOnce(&Self) -> bool,

Converts self into a Left variant of Either<Self, Self> if into_left(&self) returns true. Converts self into a Right variant of Either<Self, Self> otherwise. 阅读更多
源代码

impl<T> Pointable for T

源代码

const ALIGN: usize

指针的对齐方式。
源代码

type Init = T

初始化器的类型。
源代码

unsafe fn init(init: <T as Pointable>::Init) -> usize

使用给定的初始化器初始化内存。 阅读更多
源代码

unsafe fn deref<'a>(ptr: usize) -> &'a T

解引用给定的指针。 阅读更多
源代码

unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T

可变地解引用给定的指针。 阅读更多
源代码

unsafe fn drop(ptr: usize)

释放给定指针指向的对象。 阅读更多
源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

从借用数据创建自有数据,通常通过克隆实现。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

使用借用数据替换自有数据,通常通过克隆实现。 阅读更多
源代码

impl<T> ToString for T
where T: Display + ?Sized,

源代码

fn to_string(&self) -> String

将给定的值转换为 String阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

在转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

在转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。